# py-qua-tools

The qualang_tools package includes tools for writing QUA programs in Python. 

The first included tool is the baking tool for working with waveforms at a 1ns resolution. 

## installation

Install the current version using `pip`

```
pip install qualang-tools
```

## usage

Examples for 1-qubit randomized benchamrking or cross-entropy benchmark (XEB) can be found in the examples folder of the [py-qua-tools repository](https://github.com/qua-platform/py-qua-tools/)


